import { ref, onMounted, readonly } from 'nativescript-vue';
import { unrefView } from '../unrefView';
import { toDeviceIndependent } from '../utils';
/**
 * Reactive content size of a NativeScript view.
 *
 * @param target
 * @param options
 */
export function useContentElementSize(target, options) {
    const { initialSize = {
        width: 0,
        height: 0,
        fullWidth: 0,
        fullHeight: 0,
        marginTop: 0,
        marginBottom: 0,
        marginLeft: 0,
        marginRight: 0,
    }, } = options ?? {};
    const width = ref(initialSize.width);
    const fullWidth = ref(initialSize.width);
    const height = ref(initialSize.height);
    const fullHeight = ref(initialSize.height);
    const marginTop = ref(initialSize.marginTop);
    const marginBottom = ref(initialSize.marginBottom);
    const marginLeft = ref(initialSize.marginLeft);
    const marginRight = ref(initialSize.marginRight);
    function layoutChanged() {
        const parent = unrefView(target);
        if (parent) {
            let computeWidth = 0;
            let computeHeight = 0;
            let computeMarginTop = 0;
            let computeMarginBottom = 0;
            let computeMarginLeft = 0;
            let computeMarginRight = 0;
            parent.eachChildView((child) => {
                computeWidth += child.getActualSize().width;
                computeHeight += child.getActualSize().height;
                computeMarginTop += toDeviceIndependent(child.marginTop);
                computeMarginBottom += toDeviceIndependent(child.marginBottom);
                computeMarginLeft += toDeviceIndependent(child.marginLeft);
                computeMarginRight += toDeviceIndependent(child.marginRight);
                return true;
            });
            width.value = computeWidth;
            height.value = computeHeight;
            marginTop.value = computeMarginTop;
            marginBottom.value = computeMarginBottom;
            marginLeft.value = computeMarginLeft;
            marginRight.value = computeMarginRight;
            const computeFullWidth = (fullWidth.value = computeWidth + computeMarginLeft + computeMarginRight);
            const computeFullHeight = (fullHeight.value = computeHeight + computeMarginTop + computeMarginBottom);
            if (options?.onChange) {
                options.onChange({
                    width: computeWidth,
                    fullWidth: computeFullWidth,
                    height: computeHeight,
                    fullHeight: computeFullHeight,
                    marginTop: computeMarginTop,
                    marginBottom: computeMarginBottom,
                    marginLeft: computeMarginLeft,
                    marginRight: computeMarginRight,
                });
            }
        }
    }
    onMounted(() => {
        const view = unrefView(target);
        if (view) {
            view.on('layoutChanged', layoutChanged);
            view.eachChildView((child) => {
                child.on('layoutChanged', layoutChanged);
                return true;
            });
            view.on('unloaded', () => {
                view.off('layoutChanged', layoutChanged);
            });
            view.eachChildView((child) => {
                child.on('unloaded', () => {
                    child.off('layoutChanged', layoutChanged);
                });
                return true;
            });
        }
    });
    return {
        width: readonly(width),
        fullWidth: readonly(fullWidth),
        height: readonly(height),
        fullHeight: readonly(fullHeight),
        marginTop: readonly(marginTop),
        marginBottom: readonly(marginBottom),
        marginLeft: readonly(marginLeft),
        marginRight: readonly(marginRight),
    };
}
//# sourceMappingURL=index.js.map